const env = "__ENV__"

import wepy from "wepy";
import { md5 } from "md5";


export const config = {
    'api': (() => {
        let envMap = {
            'dev': 'https://test.plus.duowan.com/',//本地&测试            
            'preview': 'https://new.plus.duowan.com/',		//预发布
            'production': 'https://plus.duowan.com/',	//线上
        }

        return envMap[env]
    })(),
    'plusApi': (() => {
        let envMap = {
            // 'dev': 'http://test-www-27l.duowan.com/',//本地&测试
            'dev': 'https://test-xyxbox.duowan.com/',//本地&测试            
            'preview': 'https://new-xyxbox.duowan.com/',		//预发布
            'production': 'https://xyxbox.duowan.com/',	//线上
        }

        return envMap[env]
    })(),
    'shop_id': 18,
    "shareImg" : 'http://img.dwstatic.com/www/xyx-box/share-img-1.0.jpg',
    "appid": 29
    


}

export const lib = {
    encodePwd(random, pwd) {
        var k1 = md5.sha1(random);
        var k2 = md5.sha1(k1);

        var v = md5.xor(md5.xor(pwd, k2), k1);
        return md5.base64encode(v);
    },

    //任务上报
    reportTask(task_id) { //glancePlayMinute:看视频;share:分享;daySign:每日签到
        let loginData = wx.getStorageSync('loginData')

        if (!task_id && !loginData) return

        let timeStamp = (new Date()).getTime()
        let data = {
            shop_id: config.shop_id,
            task_id: task_id,
            target_id: loginData.lg_uid,
            time: timeStamp
        }
        data = Object.assign(data,loginData)

        let paramData = `shop_id=${config.shop_id}&task_id=${task_id}&target_id=${loginData.lg_uid}&time=${timeStamp}`
        data["sign"] = this.encodePwd(loginData.lg_token, md5.sha1(paramData));

        return new Promise((resolve, reject) => {
            wepy
                .request({
                    url: `${config.plusApi}/task/report`,
                    data: data
                }).then(({ data }) => {
                    if (data.code == 0) {
                        resolve(true)
                    } else {
                        resolve(false)
                    }
                })
        })
    },

    request(data,url,method = 'GET') {
       
        return new Promise((resolve,reject) => {
            let loginData = wx.getStorageSync("loginData")
            let param = Object.assign(data,loginData)
            wepy.request({
                url: `${config.plusApi}${url}`,
                data:param,
                method:method
            }).then(({data}) => {
                if (data.code == 0) {
                    resolve(data.data)
                }else {
                    wx.showToast({title: data.msg,icon: 'none',duration:3000})
                    reject(data)
                }
            }).catch((e) => {
                reject(e)
                console.log(e)
            })
        })
    },

    //对象串query
    parseParam(data) {
        let i = 0;
        var paramStr = ''
        for(var key in data) {
            if(i == 0) {
                paramStr += `?${key}=${data[key]}`
            }else {
                paramStr += `&${key}=${data[key]}`
            }
            i++
        }
        return paramStr
    },

    //渲染任务数目
    renderTaskMsg() {
        this.request({}, 'task/newList').then(ret => {
            let msgCount = ret.complete.doing
            if (msgCount) {
                wx.setTabBarBadge({
                    index: 1,
                    text: msgCount + ''
                })
            }

        })
    },

    //跳转小程序
    //小程序默认路径pages/index
    //小游戏默认路径pages/index/index
    turnToMp(app_id,path="pages/index/index",extraData={}) {
        wx.navigateToMiniProgram({
            appId: app_id,
            path,
            extraData,
            success(ret) {
                console.log(ret);
            },
            fail(ret) {
                console.log(ret);
            }
        });
    },

    //是否登录
    isLogin() {
        return wx.getStorageSync("loginData") ? true : false
    }


}

